@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import (
     AnomalySeverityType,
@@ -1024,8 +1024,8 @@ ResponseMetadataTypeDef = TypedDict(
 SearchInsightsFiltersTypeDef = TypedDict(
     "SearchInsightsFiltersTypeDef",
     {
-        "Severities": List[InsightSeverityType],
-        "Statuses": List[InsightStatusType],
+        "Severities": Sequence[InsightSeverityType],
+        "Statuses": Sequence[InsightStatusType],
         "ResourceCollection": "ResourceCollectionTypeDef",
         "ServiceCollection": "ServiceCollectionTypeDef",
     },
@@ -1154,7 +1154,7 @@ StartTimeRangeTypeDef = TypedDict(
 UpdateCloudFormationCollectionFilterTypeDef = TypedDict(
     "UpdateCloudFormationCollectionFilterTypeDef",
     {
-        "StackNames": List[str],
+        "StackNames": Sequence[str],
     },
     total=False,
 )
